@@ -1,12 +1,21 @@
 '''
 File: couchdblogger.py
 Author: Rinat F Sabitov, Federico Gonzalez
-Description:
+Description: simple python logger handler for CouchDB
 '''
 import logging
 import json
 import requests
 
+__author__ = "Rinat F Sabitov, Federico Gonzalez"
+__copyright__ = "Copyright 2015, The Cogent Project"
+__credits__ = ["Rinat F Sabitov", "Federico Gonzalez"]
+__license__ = "MIT"
+__version__ = "0.1.1"
+__maintainer__ = "Rinat Sabitov"
+__email__ = "rinat.sabitov@gmail.com"
+__status__ = "Development"
+
 
 class CouchDBSession(requests.Session):
     """
